##ABOUT
This is a mini deep learning framework created by xiaohaipeng @tianjin

##Features

+ Define Dynamic Computing Graph
+ Define Neural Network Operator
+ Define Placeholder,Linear,Sigmoid,Relu,MSE
+ Auto-Diff Computing
+ Auto-Feedforward and Backward

#Remain
+ Classification
+ Cross-Entropy
+ CNN, RNN

# Connection
wechat:18651271973
Mail:307153814@qq.com